@@ -21,13 +21,13 @@
 #ifndef __GARCON_GTK_H__
 #define __GARCON_GTK_H__
 
-#include <gtk/gtk.h>
 #include <garcon/garcon.h>
+#include <gtk/gtk.h>
 
-#define GARCON_INSIDE_GARCON_GTK_H
+#define _GARCON_INSIDE_GARCON_GTK_H
 
 #include <garcon-gtk/garcon-gtk-menu.h>
 
-#undef GARCON_INSIDE_GARCON_GTK_H
+#undef _GARCON_INSIDE_GARCON_GTK_H
 
 #endif /* !__GARCON_GTK_H__ */
